package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.TaRaiseRecord;
import com.huiju.estateagents.service.ITaRaiseRecordService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * <p>
    * 认筹单(认筹记录表)  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2020-02-26
 */
@RestController
@RequestMapping("/")
public class TaRaiseRecordController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaRaiseRecordController.class);

    @Autowired
    public ITaRaiseRecordService iTaRaiseRecordService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taRaiseRecord",method= RequestMethod.GET)
    public ResponseBean taRaiseRecordList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                          @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaRaiseRecord> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaRaiseRecord> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaRaiseRecord> result = iTaRaiseRecordService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taRaiseRecordList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taRaiseRecord 实体对象
     * @return
     */
    @RequestMapping(value="/taRaiseRecord",method= RequestMethod.POST)
    public ResponseBean taRaiseRecordAdd(@RequestBody TaRaiseRecord taRaiseRecord){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaRaiseRecordService.save(taRaiseRecord)){
                responseBean.addSuccess(taRaiseRecord);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taRaiseRecordAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taRaiseRecord/{id}", method= RequestMethod.DELETE)
    public ResponseBean taRaiseRecordDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaRaiseRecordService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taRaiseRecordDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taRaiseRecord 实体对象
     * @return
     */
    @RequestMapping(value="/taRaiseRecord/{id}",method= RequestMethod.PUT)
    public ResponseBean taRaiseRecordUpdate(@PathVariable Integer id,
                                        @RequestBody TaRaiseRecord taRaiseRecord){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaRaiseRecordService.updateById(taRaiseRecord)){
                responseBean.addSuccess(taRaiseRecord);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taRaiseRecordUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taRaiseRecord/{id}",method= RequestMethod.GET)
    public ResponseBean taRaiseRecordGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaRaiseRecordService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taRaiseRecordDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
