package com.huiju.estateagents.controller;

import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.wxpay.WXPayConstants;
import com.huiju.estateagents.common.wxpay.WXPayUtil;
import com.huiju.estateagents.entity.TaOrder;
import com.huiju.estateagents.service.IWxPayService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.io.ByteArrayOutputStream;
import java.io.InputStream;
import java.util.HashMap;
import java.util.Map;

@Slf4j
@RestController
@RequestMapping("/api")
public class WxPayController extends BaseController {

    @Autowired
    private IWxPayService wxPayService;

    /**
     * 微信统一下单接口
     * @param taOrder
     * @param request
     * @return
     */
    @RequestMapping(value = "/wx/unifiedOrder",method = RequestMethod.POST)
    public ResponseBean wxUnifiedOrder(@RequestBody TaOrder taOrder,
                                       HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            taOrder.setOrgId(getOrgId(request));
            taOrder.setPersonId(getPersonId(request));
            responseBean = wxPayService.payUnifiedOrder(taOrder,request.getRemoteAddr());
        } catch (Exception e) {
            log.error("微信统一下单失败： {}" , e.getMessage());
            responseBean.addError(e.getMessage());
            return responseBean;
        }
        return responseBean;
    }

    @RequestMapping(value = "/notify/{type}",method = RequestMethod.POST)
    public String wxBillNotify(@PathVariable String type, HttpServletRequest request){
        log.info("支付成功回调开始，支付类型是{}",type);
        String failResult = "<xml>" + "<return_code><![CDATA[FAIL]]></return_code>" + "<return_msg><![CDATA[失败]]></return_msg>" + "</xml> ";
        String successResult = "<xml>" + "<return_code><![CDATA[SUCCESS]]></return_code>" + "<return_msg><![CDATA[OK]]></return_msg>" + "</xml> ";
        Map<String, String> resultMap = new HashMap<>();
        try {
            InputStream inStream = request.getInputStream();
            ByteArrayOutputStream outSteam = new ByteArrayOutputStream();
            byte[] buffer = new byte[1024];
            int len = 0;
            while ((len = inStream.read(buffer)) != -1) {
                outSteam.write(buffer, 0, len);
            }

            // 获取微信调用我们notify_url的返回信息
            String result = new String(outSteam.toByteArray(), "utf-8");
            log.info("wxnotify:微信支付----result----=" + result);

            // 关闭流
            outSteam.close();
            inStream.close();
            // xml转换为map
            resultMap = WXPayUtil.xmlToMap(result);
            //处理业务需求
            if (WXPayConstants.SUCCESS.equalsIgnoreCase(resultMap.get("result_code"))) {
                wxPayService.wxNotify(resultMap, type);
            }else {
                log.error("支付回调出错{}",resultMap.get("return_msg"));
                return failResult;
            }

        } catch (Exception e) {
            log.error("支付回调出错{}",e.getMessage());
            return failResult;
        }

        return successResult;
    }

}
